Development environment setup instructions — goscalecms 0.3 documentation

### Navigation

- index
- next |
- previous |
- goscalecms 0.3 documentation »

# Development environment setup instructions

## System-wide packages (sudo) (setup.sh attached)

Make sure you have following ubuntu packages installed:

    sudo apt-get install mysql-server libxml2-dev libxslt1-dev python-dev python-mysqldb python-psycopg2 libevent-1.4* libevent-core-1.4* libevent-dev

And following python packages installed:

    sudo easy_install pip
    sudo easy_install -U gunicorn
    sudo pip install virtualenvwrapper
    echo "source /usr/local/bin/virtualenvwrapper.sh" >> ~/.bashrc
    source ~/.bashrc

## Python dependencies (source:requirements.txt)

Make sure to create and activate your virtualenv:

    mkvirtualenv cms
    workon cms

Always run this if some dependencies are missing (in your virtualenv activated):

    pip install -r requirements.txt

## Running the development server

This will run a gunicorn faster server with DEBUG=True:

    ./runserver.sh

### Navigation

- index
- next |
- previous |
- goscalecms 0.3 documentation »